@@ -1,11 +1,8 @@
 import pkg_resources
 
 from anonlink import blocking
-from anonlink import bloommatcher
 from anonlink import candidate_generation
 from anonlink import concurrency
-from anonlink import entitymatch
-from anonlink import network_flow
 from anonlink import serialization
 from anonlink import similarities
 from anonlink import solving
